{% extends "!base.html" %}

{%- block extrahead %}
{{ super() }}
<script async src="https://www.googletagmanager.com/gtag/js?id=G-X93W7TR6FV"></script>
<script>
  window.dataLayer = window.dataLayer || [];
  function gtag(){dataLayer.push(arguments);}
  gtag('js', new Date());

  gtag('config', 'G-X93W7TR6FV');
</script>
{% endblock %}
